translate.services.lookupclient

Package translate :: Package services :: Module lookupclient |
[hide private]
[frames] | no frames]

# Module lookupclient

source code

Small example program for querying an XML-RPC lookup service

Classes | [hide private]
| UnitClass A single term in the TBX file.

Variables | [hide private]
| server_url = `'http://localhost:1234/'`
| server = `xmlrpclib.Server(server_url)`
| text = `sys.stdin.readline()`

Imports: tbx, minidom, xmlrpclib, sys